@@ -2,6 +2,8 @@
 //!
 //! For more information, see
 //! [ANSI escape code (Wikipedia)](https://en.wikipedia.org/wiki/ANSI_escape_code).
+#[cfg(feature = "nu-ansi-term")]
+use nu_ansi_term;
 use std::collections::VecDeque;
 
 /// A `Color` can be one of the pre-defined ANSI colors (`Red`, `Green`, ..),
@@ -57,8 +59,8 @@ impl Color {
         }
     }
 
-    /// Convert to a `nu_ansi_term::Color` (if the `nu_ansi_term` feature is enabled).
-    #[cfg(feature = "nu-ansi-term")]
+    /// Convert to a `nu_ansi_term::Color` (if the `nu_ansi_term` or `gnu_legacy` feature is enabled).
+    #[cfg(any(feature = "nu-ansi-term", feature = "gnu_legacy"))]
     pub fn to_nu_ansi_term_color(&self) -> nu_ansi_term::Color {
         match self {
             Color::RGB(r, g, b) => nu_ansi_term::Color::Rgb(*r, *g, *b),
@@ -398,8 +400,51 @@ impl Style {
         }
     }
 
-    /// Convert to a `nu_ansi_term::Style` (if the `nu_ansi_term` feature is enabled).
-    #[cfg(feature = "nu-ansi-term")]
+    /// Convert to a `nu_ansi_term::Style` (if the `nu-ansi-term` or `gnu_legacy` feature is enabled).
+    ///
+    /// ## Example for nu-ansi-term feature
+    /// ```
+    /// # #[cfg(all(feature = "nu-ansi-term", not(feature = "gnu_legacy")))]
+    /// # {
+    ///
+    /// use lscolors::{Color, FontStyle, Style};
+    ///
+    /// let style = Style {
+    ///     font_style: FontStyle {
+    ///         bold: true,
+    ///         ..Default::default()
+    ///     },
+    ///     foreground: Some(Color::Blue),
+    ///     ..Default::default()
+    /// };
+    /// let nu_ansi = style.to_nu_ansi_term_style();
+    /// assert_eq!("\x1b[1;34mwow\x1b[0m", nu_ansi.paint("wow").to_string());
+    /// # }
+    /// ```
+    /// ## Example for gnu_legacy feature
+    /// ```
+    /// # #[cfg(feature = "gnu_legacy")]
+    /// # {
+    ///
+    /// use lscolors::{Color, FontStyle, Style};
+    ///
+    /// let style = Style {
+    ///     font_style: FontStyle {
+    ///         bold: true,
+    ///         ..Default::default()
+    ///     },
+    ///     foreground: Some(Color::Blue),
+    ///     ..Default::default()
+    /// };
+    /// let nu_ansi = style.to_nu_ansi_term_style();
+    /// assert_eq!(
+    ///     "\u{1b}[0m\u{1b}[01;34mwow\u{1b}[0m",
+    ///     nu_ansi.paint("wow").to_string()
+    /// );
+    /// # }
+    /// ```
+    ///
+    #[cfg(any(feature = "nu-ansi-term", feature = "gnu_legacy"))]
     pub fn to_nu_ansi_term_style(&self) -> nu_ansi_term::Style {
         nu_ansi_term::Style {
             foreground: self.foreground.as_ref().map(Color::to_nu_ansi_term_color),
@@ -412,6 +457,10 @@ impl Style {
             is_reverse: self.font_style.reverse,
             is_hidden: self.font_style.hidden,
             is_strikethrough: self.font_style.strikethrough,
+            #[cfg(feature = "gnu_legacy")]
+            prefix_with_reset: true,
+            #[cfg(not(feature = "gnu_legacy"))]
+            prefix_with_reset: false,
         }
     }
 
@@ -429,7 +478,7 @@ impl Style {
 
 #[cfg(test)]
 mod tests {
-    use super::{Color, FontStyle, Style};
+    use super::*;
 
     fn assert_style(
         code: &str,
@@ -608,4 +657,129 @@ mod tests {
             FontStyle::bold(),
         );
     }
+
+    #[cfg(all(feature = "nu-ansi-term", not(feature = "gnu_legacy")))]
+    #[test]
+    fn coloring_nu_ansi_term() {
+        let style = Style {
+            font_style: FontStyle {
+                bold: true,
+                ..Default::default()
+            },
+            foreground: Some(Color::Blue),
+            ..Default::default()
+        };
+        let nu_ansi = style.to_nu_ansi_term_style();
+        assert_eq!("\x1b[1;34mwow\x1b[0m", nu_ansi.paint("wow").to_string());
+    }
+
+    #[cfg(all(feature = "nu-ansi-term", not(feature = "gnu_legacy")))]
+    #[test]
+    fn coloring_nu_ansi_term_with_reset() {
+        let style = Style {
+            font_style: FontStyle {
+                bold: true,
+                ..Default::default()
+            },
+            foreground: Some(Color::Blue),
+            ..Default::default()
+        };
+        let nu_ansi = style.to_nu_ansi_term_style().reset_before_style();
+        assert_eq!(
+            "\x1b[0m\x1b[1;34mwow\x1b[0m",
+            nu_ansi.paint("wow").to_string()
+        );
+    }
+
+    #[cfg(feature = "gnu_legacy")]
+    #[test]
+    fn coloring_gnu_legacy() {
+        let style = Style {
+            font_style: FontStyle {
+                bold: true,
+                ..Default::default()
+            },
+            foreground: Some(Color::Blue),
+            ..Default::default()
+        };
+        let nu_ansi = style.to_nu_ansi_term_style();
+        assert_eq!(
+            "\u{1b}[0m\u{1b}[01;34mwow\u{1b}[0m",
+            nu_ansi.paint("wow").to_string()
+        );
+    }
+
+    #[cfg(feature = "gnu_legacy")]
+    #[test]
+    fn coloring_gnu_legacy_with_reset() {
+        let style = Style {
+            font_style: FontStyle {
+                bold: true,
+                ..Default::default()
+            },
+            foreground: Some(Color::Blue),
+            ..Default::default()
+        };
+        let nu_ansi = style.to_nu_ansi_term_style().reset_before_style();
+        assert_eq!(
+            "\x1b[0m\x1b[01;34mwow\x1b[0m",
+            nu_ansi.paint("wow").to_string()
+        );
+    }
+
+    #[cfg(feature = "gnu_legacy")]
+    #[test]
+    fn coloring_gnu_legacy_base() {
+        let style = Style {
+            ..Default::default()
+        };
+        let nu_ansi = style.to_nu_ansi_term_style();
+        assert_eq!(
+            "\u{1b}[0m\u{1b}[mwow\u{1b}[0m",
+            nu_ansi.paint("wow").to_string()
+        );
+    }
+
+    #[cfg(feature = "gnu_legacy")]
+    #[test]
+    fn coloring_gnu_legacy_base_with_reset() {
+        let style = Style {
+            ..Default::default()
+        };
+        let nu_ansi = style.to_nu_ansi_term_style().reset_before_style();
+        assert_eq!("\x1b[0m\x1b[mwow\x1b[0m", nu_ansi.paint("wow").to_string());
+    }
+
+    #[cfg(feature = "ansi_term")]
+    #[test]
+    fn coloring_ansi_term() {
+        let style = Style {
+            font_style: FontStyle {
+                bold: true,
+                ..Default::default()
+            },
+            foreground: Some(Color::Blue),
+            ..Default::default()
+        };
+        let ansi = style.to_ansi_term_style();
+        assert_eq!("\x1b[1;34mwow\x1b[0m", ansi.paint("wow").to_string());
+    }
+
+    #[cfg(feature = "crossterm")]
+    #[test]
+    fn coloring_crossterm() {
+        let style = Style {
+            font_style: FontStyle {
+                bold: true,
+                ..Default::default()
+            },
+            foreground: Some(Color::Blue),
+            ..Default::default()
+        };
+        let cross = style.to_crossterm_style();
+        assert_eq!(
+            "\x1b[38;5;4m\x1b[1mwow\x1b[0m",
+            cross.apply("wow").to_string()
+        );
+    }
 }
